==> kubernetes-model-core-5.7.4-sources.jar: io/fabric8/kubernetes/api/model/ExecConfigFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ExecConfigFluent<A extends io.fabric8.kubernetes.api.model.ExecConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public A addToArgs(java.lang.Integer index,java.lang.String item);
  public A setToArgs(java.lang.Integer index,java.lang.String item);
  public A addToArgs(java.lang.String... items);
  public A addAllToArgs(java.util.Collection<java.lang.String> items);
  public A removeFromArgs(java.lang.String... items);
  public A removeAllFromArgs(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getArgs();
  public java.lang.String getArg(java.lang.Integer index);
  public java.lang.String getFirstArg();
  public java.lang.String getLastArg();
  public java.lang.String getMatchingArg(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingArg(java.util.function.Predicate<java.lang.String> predicate);
  public A withArgs(java.util.List<java.lang.String> args);
  public A withArgs(java.lang.String... args);
  public java.lang.Boolean hasArgs();
  public A addNewArg(java.lang.String arg0);
  public java.lang.String getCommand();
  public A withCommand(java.lang.String command);
  public java.lang.Boolean hasCommand();
  
  /**
   * Method is deprecated. use withCommand instead.
   */
  @java.lang.Deprecated
  public A withNewCommand(java.lang.String arg0);
  public A addToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.ExecEnvVar item);
  public A setToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.ExecEnvVar item);
  public A addToEnv(io.fabric8.kubernetes.api.model.ExecEnvVar... items);
  public A addAllToEnv(java.util.Collection<io.fabric8.kubernetes.api.model.ExecEnvVar> items);
  public A removeFromEnv(io.fabric8.kubernetes.api.model.ExecEnvVar... items);
  public A removeAllFromEnv(java.util.Collection<io.fabric8.kubernetes.api.model.ExecEnvVar> items);
  public A removeMatchingFromEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ExecEnvVarBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildEnv instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.ExecEnvVar> getEnv();
  public java.util.List<io.fabric8.kubernetes.api.model.ExecEnvVar> buildEnv();
  public io.fabric8.kubernetes.api.model.ExecEnvVar buildEnv(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.ExecEnvVar buildFirstEnv();
  public io.fabric8.kubernetes.api.model.ExecEnvVar buildLastEnv();
  public io.fabric8.kubernetes.api.model.ExecEnvVar buildMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ExecEnvVarBuilder> predicate);
  public java.lang.Boolean hasMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ExecEnvVarBuilder> predicate);
  public A withEnv(java.util.List<io.fabric8.kubernetes.api.model.ExecEnvVar> env);
  public A withEnv(io.fabric8.kubernetes.api.model.ExecEnvVar... env);
  public java.lang.Boolean hasEnv();
  public A addNewEnv(java.lang.String name,java.lang.String value);
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> addNewEnv();
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> addNewEnvLike(io.fabric8.kubernetes.api.model.ExecEnvVar item);
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> setNewEnvLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.ExecEnvVar item);
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> editEnv(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> editFirstEnv();
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> editLastEnv();
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> editMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ExecEnvVarBuilder> predicate);
  public java.lang.String getInstallHint();
  public A withInstallHint(java.lang.String installHint);
  public java.lang.Boolean hasInstallHint();
  
  /**
   * Method is deprecated. use withInstallHint instead.
   */
  @java.lang.Deprecated
  public A withNewInstallHint(java.lang.String arg0);
  public java.lang.Boolean getProvideClusterInfo();
  public A withProvideClusterInfo(java.lang.Boolean provideClusterInfo);
  public java.lang.Boolean hasProvideClusterInfo();
  public interface EnvNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ExecEnvVarFluent<io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<N>>{
    public N and();
    public N endEnv();
    
  }
  
}

==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/ExecConfigFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ExecConfigFluent<A extends io.fabric8.kubernetes.api.model.ExecConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public A addToArgs(java.lang.Integer index,java.lang.String item);
  public A setToArgs(java.lang.Integer index,java.lang.String item);
  public A addToArgs(java.lang.String... items);
  public A addAllToArgs(java.util.Collection<java.lang.String> items);
  public A removeFromArgs(java.lang.String... items);
  public A removeAllFromArgs(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getArgs();
  public java.lang.String getArg(java.lang.Integer index);
  public java.lang.String getFirstArg();
  public java.lang.String getLastArg();
  public java.lang.String getMatchingArg(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingArg(java.util.function.Predicate<java.lang.String> predicate);
  public A withArgs(java.util.List<java.lang.String> args);
  public A withArgs(java.lang.String... args);
  public java.lang.Boolean hasArgs();
  public A addNewArg(java.lang.String arg0);
  public java.lang.String getCommand();
  public A withCommand(java.lang.String command);
  public java.lang.Boolean hasCommand();
  
  /**
   * Method is deprecated. use withCommand instead.
   */
  @java.lang.Deprecated
  public A withNewCommand(java.lang.String arg0);
  public A addToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.ExecEnvVar item);
  public A setToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.ExecEnvVar item);
  public A addToEnv(io.fabric8.kubernetes.api.model.ExecEnvVar... items);
  public A addAllToEnv(java.util.Collection<io.fabric8.kubernetes.api.model.ExecEnvVar> items);
  public A removeFromEnv(io.fabric8.kubernetes.api.model.ExecEnvVar... items);
  public A removeAllFromEnv(java.util.Collection<io.fabric8.kubernetes.api.model.ExecEnvVar> items);
  public A removeMatchingFromEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ExecEnvVarBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildEnv instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.ExecEnvVar> getEnv();
  public java.util.List<io.fabric8.kubernetes.api.model.ExecEnvVar> buildEnv();
  public io.fabric8.kubernetes.api.model.ExecEnvVar buildEnv(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.ExecEnvVar buildFirstEnv();
  public io.fabric8.kubernetes.api.model.ExecEnvVar buildLastEnv();
  public io.fabric8.kubernetes.api.model.ExecEnvVar buildMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ExecEnvVarBuilder> predicate);
  public java.lang.Boolean hasMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ExecEnvVarBuilder> predicate);
  public A withEnv(java.util.List<io.fabric8.kubernetes.api.model.ExecEnvVar> env);
  public A withEnv(io.fabric8.kubernetes.api.model.ExecEnvVar... env);
  public java.lang.Boolean hasEnv();
  public A addNewEnv(java.lang.String name,java.lang.String value);
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> addNewEnv();
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> addNewEnvLike(io.fabric8.kubernetes.api.model.ExecEnvVar item);
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> setNewEnvLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.ExecEnvVar item);
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> editEnv(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> editFirstEnv();
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> editLastEnv();
  public io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<A> editMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.ExecEnvVarBuilder> predicate);
  public java.lang.String getInstallHint();
  public A withInstallHint(java.lang.String installHint);
  public java.lang.Boolean hasInstallHint();
  
  /**
   * Method is deprecated. use withInstallHint instead.
   */
  @java.lang.Deprecated
  public A withNewInstallHint(java.lang.String arg0);
  public java.lang.String getInteractiveMode();
  public A withInteractiveMode(java.lang.String interactiveMode);
  public java.lang.Boolean hasInteractiveMode();
  
  /**
   * Method is deprecated. use withInteractiveMode instead.
   */
  @java.lang.Deprecated
  public A withNewInteractiveMode(java.lang.String arg0);
  public java.lang.Boolean getProvideClusterInfo();
  public A withProvideClusterInfo(java.lang.Boolean provideClusterInfo);
  public java.lang.Boolean hasProvideClusterInfo();
  public interface EnvNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ExecEnvVarFluent<io.fabric8.kubernetes.api.model.ExecConfigFluent.EnvNested<N>>{
    public N and();
    public N endEnv();
    
  }
  
}
